
# -*- coding: utf-8 -*-

from recommonmark.parser import CommonMarkParser

templates_path = ['_templates']
source_suffix = '.md'
source_parsers = { '.md': CommonMarkParser }
master_doc = 'index'
project = u'sphinxproj'
copyright = u'2015, rtfd'
author = u'rtfd'
version = '0.1'
release = '0.1'
language = None
exclude_patterns = ['_build']
highlight_language = 'python'
pygments_style = 'sphinx'
todo_include_todos = False
html_theme = 'alabaster'
html_static_path = ['_static']
htmlhelp_basename = 'sphinxproj'



import os
import io
import sys
import shutil
import unittest
from contextlib import contextmanager

from sphinx.application import Sphinx


@contextmanager
def sphinx_built_file(test_dir, test_file):
    os.chdir('tests/{0}'.format(test_dir))
    try:
        app = Sphinx(
            srcdir='.',
            confdir='.',
            outdir='_build/text',
            doctreedir='_build/.doctrees',
            buildername='html',
            verbosity=1,
        )
        app.build(force_all=True)
        with io.open(test_file, encoding='utf-8') as fin:
            yield fin.read().strip()
    finally:
        shutil.rmtree('_build')
        os.chdir('../..')


def run_test(test_dir, test_file, test_string):
    with sphinx_built_file(test_dir, test_file) as output:
        assert test_string in output


class SphinxIntegrationTests(unittest.TestCase):

    build_path = None

    def setUp(self):
        if self.build_path is not None:
            self.app = Sphinx(
                srcdir=self.build_path,
                confdir=self.build_path,
                outdir=os.path.join(self.build_path, '_build', 'text'),
                doctreedir=os.path.join(self.build_path, '_build', '.doctrees'),
                buildername='html',
                verbosity=1,
            )
            self.app.build(force_all=True)

    def tearDown(self):
        if self.build_path is not None:
            shutil.rmtree(os.path.join(self.build_path, '_build'))

    def read_file(self, path):
        full_path = os.path.join(self.build_path, '_build', 'text', path)
        with io.open(full_path, encoding='utf-8') as h:
            return h.read().strip()


class GenericTests(SphinxIntegrationTests):

    build_path = 'tests/sphinx_generic'

    def test_headings(self):
        output = self.read_file('index.html')
        self.assertIn(
            ('<h1>Heading 1'
             '<a class="headerlink" '
             'href="#heading-1" '
             u'title="Permalink to this headline">\xb6</a>'
             '</h1>'),
            output,
        )
        self.assertIn(
            ('<h2>Heading 2'
             '<a class="headerlink" '
             'href="#heading-2" '
             u'title="Permalink to this headline">\xb6</a>'
             '</h2>'),
            output,
        )
        self.assertIn(
            ('<h3>Heading 3'
             '<a class="headerlink" '
             'href="#heading-3" '
             u'title="Permalink to this headline">\xb6</a>'
             '</h3>'),
            output,
        )
        self.assertIn(
            ('<h4>Heading 4'
             '<a class="headerlink" '
             'href="#heading-4" '
             u'title="Permalink to this headline">\xb6</a>'
             '</h4>'),
            output,
        )

    def test_links(self):
        output = self.read_file('index.html')
        self.assertIn(
            ('This is a '
             '<a class="reference external" '
             'href="http://example.com">link</a>'),
            output
        )
        self.assertIn(
            ('This is a '
             '<a class="reference external" '
             'href="http://example.com/foobar">ref link</a>'),
            output
        )
        self.assertIn(
            ('This is a '
             '<a class="reference external" '
             'href="/example">relative link</a>'),
            output
        )
        self.assertIn(
            ('This is a '
             '<a class="reference internal" href="#">'
             '<span class="doc">pending ref</span>'
             '</a>'),
            output
        )

    def test_image(self):
        output = self.read_file('index.html')
        self.assertIn(
            '<p><img alt="Example" src="image.png" />foo</p>',
            output
        )

    def test_paragraph(self):
        output = self.read_file('index.html')
        self.assertIn('<p>Foo</p>', output)
        self.assertIn('<p>Bar</p>', output)

    def test_lists(self):
        output = self.read_file('index.html')
        self.assertIn(
            ('<ul class="simple">\n'
             '<li>Item A</li>\n'
             '<li>Item B</li>\n'
             '<li>Item C</li>\n'
             '</ul>'),
            output
        )
        self.assertIn(
            ('<ol class="simple">\n'
             '<li>Item 1</li>\n'
             '<li>Item 2</li>\n'
             '<li>Item 3</li>\n'
             '</ol>'),
            output
        )

    def test_code(self):
        output = self.read_file('index.html')
        self.assertIn(
            ('<pre><span></span>'
             '<span class="ch">#!/bin/sh</span>\n'
             '<span class="n">python</span>\n'
             '</pre>'),
            output
        )

    def test_thematic_break(self):
        output = self.read_file('index.html')
        self.assertIn(
            '<p>Foo</p>\n<hr class="docutils" />\n<p>Bar</p>',
            output
        )


class CodeBlockTests(unittest.TestCase):

    def test_integration(self):
        with sphinx_built_file('sphinx_code_block', '_build/text/index.html') as output:
            self.assertIn('<div class="highlight">', output)


class IndentedCodeTests(unittest.TestCase):

    def test_integration(self):
        run_test(
            'sphinx_indented_code',
            '_build/text/index.html',
            '<div class="highlight">'
        )

class NestedHeaderBlock(unittest.TestCase):

    def test_integration(self):
        run_test(
            'sphinx_nested_header_block',
            '_build/text/index.html',
            '<h1>'
        )

class CustomExtensionTests(SphinxIntegrationTests):

    build_path = 'tests/sphinx_custom_md'

    def test_integration(self):
        output = self.read_file('index.html')
        self.assertIn('<table ', output)
        self.assertIn('<th class="head">abc</th>', output)
        self.assertIn('<th class="head">data</th>', output)
        self.assertIn('</table>', output)



# -*- coding: utf-8 -*-

import unittest
from textwrap import dedent

from docutils import nodes
from docutils.utils import new_document
from docutils.readers import Reader
from docutils.core import publish_parts

from CommonMark import Parser
from recommonmark.parser import CommonMarkParser


class TestParsing(unittest.TestCase):

    def assertParses(self, source, expected, alt=False):  # noqa
        parser = CommonMarkParser()
        parser.parse(dedent(source), new_document('<string>'))
        self.assertMultiLineEqual(
            dedent(expected).lstrip(),
            dedent(parser.document.asdom().toprettyxml(indent='  ')),
        )

    def test_heading(self):
        self.assertParses(
            """
            # Heading 1

            ## Heading 2

            Body
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <section ids="heading-1" names="heading\ 1">
                <title>Heading 1</title>
                <section ids="heading-2" names="heading\ 2">
                  <title>Heading 2</title>
                  <paragraph>Body</paragraph>
                </section>
              </section>
            </document>
            """
        )

    def test_heading_inline(self):
        self.assertParses(
            """# Heading *foo*""",
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <section ids="heading-foo" names="heading\ foo">
                <title>
                  Heading \n\
                  <emphasis>foo</emphasis>
                </title>
              </section>
            </document>
            """
        )

    def test_paragraph(self):
        self.assertParses(
            """This is a paragraph""",
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>This is a paragraph</paragraph>
            </document>
            """
        )
        self.assertParses(
            """This is a paragraph *foo***bar**""",
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                This is a paragraph \n\
                <emphasis>foo</emphasis>
                <strong>bar</strong>
              </paragraph>
            </document>
            """
        )
        self.assertParses(
            """
            This is a paragraph
            This is a new line
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                This is a paragraph


                This is a new line
              </paragraph>
            </document>
            """
        )

    def test_entities(self):
        self.assertParses(
            u"""
            &copy;
            """,
            u"""
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>©</paragraph>
            </document>
            """
        )

    def test_links(self):
        self.assertParses(
            """
            This is a [link](http://example.com)
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                This is a \n\
                <reference refuri="http://example.com">link</reference>
              </paragraph>
            </document>
            """
        )
        self.assertParses(
            """
            This is a [link][example]

            [example]: http://example.com "Example"
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                This is a \n\
                <reference refuri="http://example.com" title="Example">link</reference>
              </paragraph>
            </document>
            """
        )
        self.assertParses(
            """
            This is a [link][example]

            [example]: http://example.com
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                This is a \n\
                <reference refuri="http://example.com">link</reference>
              </paragraph>
            </document>
            """
        )
        self.assertParses(
            """
            <http://example.com>
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                <reference refuri="http://example.com">http://example.com</reference>
              </paragraph>
            </document>
            """
        )
        self.assertParses(
            """
            [link](/foo)
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                <pending_xref refexplicit="True" reftarget="/foo" reftype="any" refwarn="True">
                  <reference refuri="/foo">link</reference>
                </pending_xref>
              </paragraph>
            </document>
            """
        )
        self.assertParses(
            """
            [link](foo)
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                <pending_xref refexplicit="True" reftarget="foo" reftype="any" refwarn="True">
                  <reference refuri="foo">link</reference>
                </pending_xref>
              </paragraph>
            </document>
            """
        )

    def test_image(self):
        self.assertParses(
            """
            ![foo](/url "title")
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                <image alt="title" uri="/url">foo</image>
              </paragraph>
            </document>
            """
        )

    def test_inline_code(self):
        self.assertParses(
            """
            This is `code` right?
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>
                This is \n\
                <literal>code</literal>
                 right?
              </paragraph>
            </document>
            """
        )

    def test_bullet_list(self):
        self.assertParses(
            """
            * List item 1
            * List item 2
            * List item 3
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <bullet_list>
                <list_item>
                  <paragraph>List item 1</paragraph>
                </list_item>
                <list_item>
                  <paragraph>List item 2</paragraph>
                </list_item>
                <list_item>
                  <paragraph>List item 3</paragraph>
                </list_item>
              </bullet_list>
            </document>
            """
        )
        self.assertParses(
            """
            * [List item 1](/1)
            * [List item 2](/2)
            * [List item 3](/3)
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <bullet_list>
                <list_item>
                  <paragraph>
                    <pending_xref refexplicit="True" reftarget="/1" reftype="any" refwarn="True">
                      <reference refuri="/1">List item 1</reference>
                    </pending_xref>
                  </paragraph>
                </list_item>
                <list_item>
                  <paragraph>
                    <pending_xref refexplicit="True" reftarget="/2" reftype="any" refwarn="True">
                      <reference refuri="/2">List item 2</reference>
                    </pending_xref>
                  </paragraph>
                </list_item>
                <list_item>
                  <paragraph>
                    <pending_xref refexplicit="True" reftarget="/3" reftype="any" refwarn="True">
                      <reference refuri="/3">List item 3</reference>
                    </pending_xref>
                  </paragraph>
                </list_item>
              </bullet_list>
            </document>
            """
        )

    def test_enumerated_list(self):
        self.assertParses(
            """
            1. List item 1
            2. List item 2
            3. List item 3
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <enumerated_list>
                <list_item>
                  <paragraph>List item 1</paragraph>
                </list_item>
                <list_item>
                  <paragraph>List item 2</paragraph>
                </list_item>
                <list_item>
                  <paragraph>List item 3</paragraph>
                </list_item>
              </enumerated_list>
            </document>
            """
        )

    def test_code(self):
        self.assertParses(
            """
            Code:

                #!/bin/sh
                python
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>Code:</paragraph>
              <literal_block xml:space="preserve">#!/bin/sh
            python</literal_block>
            </document>
            """
        )

    def test_block_quote(self):
        self.assertParses(
            """
            > Here is a quoted list:
            > \n\
            > * Item 1
            > * Item 2
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <block_quote>
                <paragraph>Here is a quoted list:</paragraph>
                <bullet_list>
                  <list_item>
                    <paragraph>Item 1</paragraph>
                  </list_item>
                  <list_item>
                    <paragraph>Item 2</paragraph>
                  </list_item>
                </bullet_list>
              </block_quote>
            </document>
            """
        )

    def test_horizontal_rule(self):
        self.assertParses(
            """
            Foo

            ----

            Bar
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>Foo</paragraph>
              <transition/>
              <paragraph>Bar</paragraph>
            </document>
            """
        )

    def test_html(self):
        self.assertParses(
            """
            Foo

            <blink>Blink</blink>
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <paragraph>Foo</paragraph>
              <paragraph>
                <raw format="html" xml:space="preserve">&lt;blink&gt;</raw>
                Blink
                <raw format="html" xml:space="preserve">&lt;/blink&gt;</raw>
              </paragraph>
            </document>
            """
        )

    def test_eval(self):
        self.assertParses(
            """
            ```eval_rst
            .. image:: figure.png
            ```
            """,
            """
            <?xml version="1.0" ?>
            <document source="&lt;string&gt;">
              <literal_block language="eval_rst" xml:space="preserve">\
.. image:: figure.png</literal_block>
            </document>
            """
        )


if __name__ == '__main__':
    unittest.main()



"""Docutils CommonMark parser"""

__version__ = '0.4.0'


def setup(app):
    """Initialize Sphinx extension."""
    from .parser import CommonMarkParser
    app.add_source_parser('.md', CommonMarkParser)  # needs Sphinx >= 1.4
    return {'version': __version__, 'parallel_read_safe': True}




# -*- coding: utf-8 -*-

from recommonmark.parser import CommonMarkParser
from recommonmark.transform import AutoStructify

templates_path = ['_templates']
source_suffix = '.markdown'
source_parsers = { '.markdown': CommonMarkParser }
master_doc = 'index'
project = u'sphinxproj'
copyright = u'2015, rtfd'
author = u'rtfd'
version = '0.1'
release = '0.1'
language = None
exclude_patterns = ['_build']
highlight_language = 'python'
pygments_style = 'sphinx'
todo_include_todos = False
html_theme = 'alabaster'
html_static_path = ['_static']
htmlhelp_basename = 'sphinxproj'

def setup(app):
    app.add_config_value('recommonmark_config', {
            'enable_eval_rst': True,
            'commonmark_suffixes': ['.markdown', '.hpp'],
            }, True)
    app.add_transform(AutoStructify)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
File: setup.py
Author: Steve Genoud and Luca Barbato
Date: 2014-10-17
"""

from setuptools import setup
import recommonmark


setup(
    name='recommonmark',
    version=recommonmark.__version__,
    install_requires=[
        'commonmark>=0.7.3',
        'docutils>=0.11',
        'sphinx>=1.3.1',
    ],
    entry_points={'console_scripts': [
        'cm2html = recommonmark.scripts:cm2html',
        'cm2latex = recommonmark.scripts:cm2latex',
        'cm2man = recommonmark.scripts:cm2man',
        'cm2pseudoxml = recommonmark.scripts:cm2pseudoxml',
        'cm2xetex = recommonmark.scripts:cm2xetex',
        'cm2xml = recommonmark.scripts:cm2xml',
    ]},
    packages=['recommonmark']
)
